==> 3_0.zip: c.php <==
<?php
/*
n-b Ver 3

RomƂANZXƂ낢
*/

//Ƃ肠t@CbN
$lock = fopen("data/lock.txt","w");
flock($lock,LOCK_EX);

//ipƂhostƂ擾
$ip        = $_SERVER["REMOTE_ADDR"];
$host      = gethostbyaddr($ip);
$psp       = $_ENV["HTTP_X_PSP_BROWSER"];
$useragent = $_SERVER["HTTP_USER_AGENT"];
//gт̎ʔԍ擾
if (preg_match("/\.docomo\.ne\.jp/", $host)){
 $m = $_SERVER['HTTP_X_DCMGUID'];
}elseif(preg_match("/ezweb/", $host)){
 $m = $_SERVER['HTTP_X_UP_SUBNO'];
}elseif(preg_match("/\.jp-(.*)\.ne\.jp/", $host)){
 $mo = preg_match("/^.+\/SN([0-9a-zA-Z]+).*$/", $useragent, $match);
 $m = $match[1];
}
if ($m == ""){ $id = $ip; }else{ $id = $m; }
if (file_exists("data/rom.cgi")) { $ad = file_get_contents("data/rom.cgi"); }

$ee = $id."<>".time()."<>".htmlspecialchars($_SERVER["HTTP_USER_AGENT"])."<>".$_SERVER["REMOTE_ADDR"]."<>".$m."<>".htmlspecialchars($_ENV["HTTP_X_PSP_BROWSER"])."<>".htmlspecialchars($_SERVER["REQUEST_URI"]);
if ($ad != ""){
 $ee = $ee."\n".$ad;
}
file_put_contents("data/rom.cgi",$ee);

$romdata = explode("\n",$ee);
$d = 0;
$ef = count($romdata);
while($d <= $ef){
 if (preg_match("/".$id."/", $romdata[$d])){
  unset($romdata[$d]);
 }else{
  $romdata2 = explode("<>",$romdata[$d]);
  if (time() - $romdata2[1] > 300){ unset($romdata[$d]); }
 }
 $d++;
}
$romdata2 = implode("\n",$romdata);
$ee = $id."<>".time()."<>".htmlspecialchars($_SERVER["HTTP_USER_AGENT"])."<>".$_SERVER["REMOTE_ADDR"]."<>".$m."<>".htmlspecialchars($_ENV["HTTP_X_PSP_BROWSER"])."<>".htmlspecialchars($_SERVER["REQUEST_URI"]);
$romdata2 = $ee."\n".$romdata2;
file_put_contents("data/rom.cgi",$romdata2);
$romcon = count($romdata) + 1;

if (file_exists("data/count.txt")){
 $data = file_get_contents("data/count.txt");
}else{
 $data = "0<>".date("Y/m/d")."<>0<>0<>";
}

$t = date("Y/m/d");
$data = explode("<>",$data);
$today = $data[0];
$today_2 = $data[1];
$yest = $data[2];
$total = $data[3];
if ($today_2 == $t){ $today_2 = $t; }else{ $yest = $today; file_put_contents("clog/".date("Y-m-d").".txt",$yest); $today = 0; $today_2 = $t; }
$today++;
$total++;
$data = $today."<>".$today_2."<>".$yest."<>".$total;
file_put_contents("data/count.txt",$data);


$data = explode("<>",$data);
$t = $data[0];
$y = $data[2];
$tol = $data[3];

fclose($lock);

==> 3_1.zip: c.php <==
<?php
/*
n-b Ver 3

RomƂANZXƂ낢
*/
//c΍
if (file_exists("count/c.txt")){
 $a = file_get_contents("count/c.txt");
}else{
 $a = time()."<>0";
}
$tt = explode("<>",$a);
$aa = time()-$tt[0];
$g = $tt[1];
//$aa = 0; $g = 11;
//$aa = 2;
if (file_exists("data/err_log2.txt")){
 $f = file_get_contents("data/err_log2.txt");
}
$ff = $_SERVER["REMOTE_ADDR"];
preg_match_all("/${ff}/",$f,$md);
$l = 6;
if (date("H") >= 0 and date("H") < 7) { $l = 10; }
elseif (date("H") >= 7 and date("H") < 11) { $l = 20; }
elseif (date("H") >= 11 and date("H") < 17) { $l = 15; }
elseif (date("H") >= 17 and date("H") < 24) { $l = 10; }
else{ $l = 6; }

if(count($md[0]) <= 5){
 if ($aa <= 1){
  if ($g > $l){ echo "ʃANZXm܂B"; err(999); exit;}
 }else{
  $g = 0;
 }
}else{
 echo "l̑ʃANZX5񌟒m߃ANZX֎~ɂĂ܂"; exit;
}

$g++;
file_put_contents("count/c.txt",time()."<>".$g);

//Ƃ肠t@CbN
$lock = fopen("data/lock2.txt","w");
flock($lock,LOCK_EX);

//ipƂhostƂ擾
$ip        = $_SERVER["REMOTE_ADDR"];
$host      = gethostbyaddr($ip);
$psp       = $_ENV["HTTP_X_PSP_BROWSER"];
$useragent = $_SERVER["HTTP_USER_AGENT"];
//gт̎ʔԍ擾
if (preg_match("/\.docomo\.ne\.jp/", $host)){
 $m = $_SERVER['HTTP_X_DCMGUID'];
}elseif(preg_match("/ezweb/", $host)){
 $m = $_SERVER['HTTP_X_UP_SUBNO'];
}elseif(preg_match("/\.jp-(.*)\.ne\.jp/", $host)){
 $mo = preg_match("/^.+\/SN([0-9a-zA-Z]+).*$/", $useragent, $match);
 $m = $match[1];
}
if ($m == ""){ $id = $ip; }else{ $id = $m; }
if (file_exists("data/rom.cgi")) { $ad = file_get_contents("data/rom.cgi"); }

$ee = $id."<>".time()."<>".htmlspecialchars($_SERVER["HTTP_USER_AGENT"])."<>".$_SERVER["REMOTE_ADDR"]."<>".$m."<>".htmlspecialchars($_ENV["HTTP_X_PSP_BROWSER"])."<>".htmlspecialchars($_SERVER["REQUEST_URI"]);
if ($ad != ""){
 $ee = $ee."\n".$ad;
}
file_put_contents("data/rom.cgi",$ee);

$romdata = explode("\n",$ee);
$d = 0;
$ef = count($romdata);
while($d <= $ef){
 if (preg_match("/".$id."/", $romdata[$d])){
  unset($romdata[$d]);
 }else{
  $romdata2 = explode("<>",$romdata[$d]);
  if (time() - $romdata2[1] > 300){ unset($romdata[$d]); }
 }
 $d++;
}
$romdata2 = implode("\n",$romdata);
$ee = $id."<>".time()."<>".htmlspecialchars($_SERVER["HTTP_USER_AGENT"])."<>".$_SERVER["REMOTE_ADDR"]."<>".$m."<>".htmlspecialchars($_ENV["HTTP_X_PSP_BROWSER"])."<>".htmlspecialchars($_SERVER["REQUEST_URI"]);
$romdata2 = $ee."\n".$romdata2;
file_put_contents("data/rom.cgi",$romdata2);
$romcon = count($romdata) + 1;

if (file_exists("data/count.txt")){
 $data = file_get_contents("data/count.txt");
}else{
 $data = "0<>".date("Y/m/d")."<>0<>0<>";
}

$t = date("Y/m/d");
$data = explode("<>",$data);
$today = $data[0];
$today_2 = $data[1];
$yest = $data[2];
$total = $data[3];
if ($today_2 == $t){ $today_2 = $t; }else{ $yest = $today; file_put_contents("clog/".date("Y-m-d").".txt",$yest); $today = 0; $today_2 = $t; }
$today++;
$total++;
$data = $today."<>".$today_2."<>".$yest."<>".$total;
file_put_contents("data/count.txt",$data);


$data = explode("<>",$data);
$t = $data[0];
$y = $data[2];
$tol = $data[3];

fclose($lock);
